@@ -1,7 +1,6 @@
 """
 Command Line Interfaceの共通部分
 """
-
 import abc
 import argparse
 import dataclasses
@@ -9,25 +8,35 @@ import getpass
 import json
 import logging
 import os
+import pkgutil
+from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
 
 import annofabapi
 import jmespath
 import pandas
 import requests
+import yaml
 from annofabapi.api import DEFAULT_ENDPOINT_URL
 from annofabapi.exceptions import AnnofabApiException
 from annofabapi.models import OrganizationMemberRole, ProjectMemberRole
+from more_itertools import first_true
 
-import annofabcli
 from annofabcli.common.dataclasses import WaitOptions
 from annofabcli.common.enums import FormatArgument
+from annofabcli.common.exceptions import AnnofabCliException, AuthenticationError
 from annofabcli.common.facade import AnnofabApiFacade
 from annofabcli.common.typing import InputDataSize
+from annofabcli.common.utils import (
+    DEFAULT_CSV_FORMAT,
+    get_file_scheme_path,
+    print_according_to_format,
+    print_csv,
+    read_lines_except_blank_line,
+)
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_CSV_FORMAT = {"encoding": "utf_8_sig", "index": False}
 
 COMMAND_LINE_ERROR_STATUS_CODE = 2
 """コマンドラインエラーが発生したときに返すステータスコード"""
@@ -53,7 +62,7 @@ def build_annofabapi_resource_and_login(args: argparse.Namespace) -> annofabapi.
 
     except requests.exceptions.HTTPError as e:
         if e.response.status_code == requests.codes.unauthorized:
-            raise annofabcli.exceptions.AuthenticationError(service.api.login_user_id)
+            raise AuthenticationError(service.api.login_user_id) from e
         raise e
 
 
@@ -61,7 +70,7 @@ def add_parser(
     subparsers: Optional[argparse._SubParsersAction],
     command_name: str,
     command_help: str,
-    description: str,
+    description: Optional[str] = None,
     is_subcommand: bool = True,
     epilog: Optional[str] = None,
 ) -> argparse.ArgumentParser:
@@ -72,7 +81,7 @@ def add_parser(
         subparsers:
         command_name:
         command_help: 1階層上のコマンドヘルプに表示される コマンドの説明（簡易的な説明）
-        description: ヘルプ出力に表示される説明（詳細な説明）
+        description: ヘルプ出力に表示される説明（詳細な説明）。未指定の場合は command_help と同じ値です。
         is_subcommand: サブコマンドかどうか. `annofabcli project`はコマンド、`annofabcli project list`はサブコマンドとみなす。
         epilog: ヘルプ出力後に表示される内容。デフォルトはNoneです。
 
@@ -80,6 +89,33 @@ def add_parser(
         サブコマンドのparser
 
     """
+    GLOBAL_OPTIONAL_ARGUMENTS_TITLE = "global optional arguments"
+
+    def create_parent_parser() -> argparse.ArgumentParser:
+        """
+        共通の引数セットを生成する。
+        """
+        parent_parser = argparse.ArgumentParser(add_help=False)
+        group = parent_parser.add_argument_group(GLOBAL_OPTIONAL_ARGUMENTS_TITLE)
+
+        group.add_argument("--yes", action="store_true", help="処理中に現れる問い合わせに対して、常に ``yes`` と回答します。")
+
+        group.add_argument(
+            "--endpoint_url", type=str, help=f"Annofab WebAPIのエンドポイントを指定します。指定しない場合は ``{DEFAULT_ENDPOINT_URL}`` です。"
+        )
+
+        group.add_argument(
+            "--logdir",
+            type=Path,
+            default=".log",
+            help="ログファイルを保存するディレクトリを指定します。指定しない場合は ``.log`` ディレクトリ'にログファイルが保存されます。",
+        )
+
+        group.add_argument("--disable_log", action="store_true", help="ログを無効にします。")
+
+        group.add_argument("--debug", action="store_true", help="HTTPリクエストの内容やレスポンスのステータスコードなど、デバッグ用のログが出力されます。")
+
+        return parent_parser
 
     if subparsers is None:
         subparsers = argparse.ArgumentParser().add_subparsers()
@@ -88,44 +124,27 @@ def add_parser(
     parser = subparsers.add_parser(
         command_name,
         parents=parents,
-        description=description,
+        description=description if description is not None else command_help,
         help=command_help,
         epilog=epilog,
         formatter_class=PrettyHelpFormatter,
     )
     parser.set_defaults(command_help=parser.print_help)
+
+    # 引数グループに"global optional group"がある場合は、"--help"オプションをデフォルトの"optional"グループから、"global optional arguments"グループに移動する
+    # https://ja.stackoverflow.com/a/57313/19524
+    global_optional_argument_group = first_true(
+        parser._action_groups, pred=lambda e: e.title == GLOBAL_OPTIONAL_ARGUMENTS_TITLE
+    )
+    if global_optional_argument_group is not None:
+        # optional グループの 0番目が help なので取り出す
+        help_action = parser._optionals._group_actions.pop(0)
+        assert help_action.dest == "help"
+        # global optional group の 先頭にhelpを追加
+        global_optional_argument_group._group_actions.insert(0, help_action)
     return parser
 
 
-def create_parent_parser() -> argparse.ArgumentParser:
-    """
-    共通の引数セットを生成する。
-    """
-    parent_parser = argparse.ArgumentParser(add_help=False)
-    group = parent_parser.add_argument_group("global optional arguments")
-
-    group.add_argument("--yes", action="store_true", help="処理中に現れる問い合わせに対して、常に ``yes`` と回答します。")
-
-    group.add_argument(
-        "--endpoint_url", type=str, help=f"AnnoFab WebAPIのエンドポイントを指定します。指定しない場合は ``{DEFAULT_ENDPOINT_URL}`` です。"
-    )
-
-    group.add_argument(
-        "--logdir", type=str, default=".log", help="ログファイルを保存するディレクトリを指定します。指定しない場合は ``.log`` ディレクトリ'にログファイルが保存されます。"
-    )
-
-    group.add_argument("--disable_log", action="store_true", help="ログを無効にします。")
-
-    group.add_argument(
-        "--logging_yaml",
-        type=str,
-        help="ロギグングの設定ファイル(YAML)を指定します。指定した場合、 ``--logdir`` オプションは無視されます。"
-        "指定しない場合、デフォルトのロギングが設定されます。"
-        "設定ファイルの書き方は https://docs.python.org/ja/3/howto/logging.html 参照してください。",
-    )
-    return parent_parser
-
-
 def get_list_from_args(str_list: Optional[List[str]] = None) -> List[str]:
     """
     文字列のListのサイズが1で、プレフィックスが`file://`ならば、ファイルパスとしてファイルを読み込み、行をListとして返す。
@@ -145,9 +164,9 @@ def get_list_from_args(str_list: Optional[List[str]] = None) -> List[str]:
         return str_list
 
     str_value = str_list[0]
-    path = annofabcli.utils.get_file_scheme_path(str_value)
+    path = get_file_scheme_path(str_value)
     if path is not None:
-        return annofabcli.utils.read_lines_except_blank_line(path)
+        return read_lines_except_blank_line(path)
     else:
         return str_list
 
@@ -175,7 +194,7 @@ def get_json_from_args(target: Optional[str] = None) -> Any:
     if target is None:
         return None
 
-    path = annofabcli.utils.get_file_scheme_path(target)
+    path = get_file_scheme_path(target)
     if path is not None:
         with open(path, encoding="utf-8") as f:
             return json.load(f)
@@ -185,11 +204,11 @@ def get_json_from_args(target: Optional[str] = None) -> Any:
 
 def get_input_data_size(str_input_data_size: str) -> Optional[InputDataSize]:
     """400x300を(400,300)に変換する"""
-    splited_list = str_input_data_size.split("x")
-    if len(splited_list) < 2:
+    splitted_list = str_input_data_size.split("x")
+    if len(splitted_list) < 2:
         return None
 
-    return (int(splited_list[0]), int(splited_list[1]))
+    return (int(splitted_list[0]), int(splitted_list[1]))
 
 
 def get_wait_options_from_args(
@@ -230,12 +249,26 @@ def load_logging_config_from_args(args: argparse.Namespace) -> None:
     if args.disable_log:
         return
 
-    annofabcli.utils.load_logging_config(args.logdir, args.logging_yaml)
+    data = pkgutil.get_data("annofabcli", "data/logging.yaml")
+    if data is None:
+        logger.warning("annofabcli/data/logging.yaml が読み込めませんでした")
+        raise AnnofabCliException("annofabcli/data/logging.yaml が読み込めませんでした")
+
+    logging_config = yaml.safe_load(data.decode("utf-8"))
+
+    log_file = args.logdir / "annofabcli.log"
+    log_file.parent.mkdir(exist_ok=True, parents=True)
+    logging_config["handlers"]["fileRotatingHandler"]["filename"] = str(log_file)
+
+    if args.debug:
+        logging_config["loggers"]["annofabapi"]["level"] = "DEBUG"
+
+    logging.config.dictConfig(logging_config)
 
 
 def get_endpoint_url(args: argparse.Namespace) -> str:
     """
-    AnnoFab WebAPIのエンドポイントURLを、以下の優先順位で取得する。
+    Annofab WebAPIのエンドポイントURLを、以下の優先順位で取得する。
 
     1. コマンドライン引数 ``--endpoint_url``
     2. 環境変数 ``ANNOFAB_ENDPOINT_URL``
@@ -246,7 +279,7 @@ def get_endpoint_url(args: argparse.Namespace) -> str:
         args: コマンドライン引数情報
 
     Returns:
-        AnnoFab WebAPIのエンドポイントURL
+        Annofab WebAPIのエンドポイントURL
 
     """
     endpoint_url = args.endpoint_url
@@ -263,7 +296,7 @@ def get_endpoint_url(args: argparse.Namespace) -> str:
 def build_annofabapi_resource(args: argparse.Namespace) -> annofabapi.Resource:
     """
     annofabapi.Resourceインスタンスを生成する。
-    以下の順にAnnoFabの認証情報を読み込む。
+    以下の順にAnnofabの認証情報を読み込む。
     1. `.netrc`ファイル
     2. 環境変数`ANNOFAB_USER_ID` , `ANNOFAB_PASSWORD`
 
@@ -275,7 +308,7 @@ def build_annofabapi_resource(args: argparse.Namespace) -> annofabapi.Resource:
     """
     endpoint_url = get_endpoint_url(args)
     if endpoint_url != DEFAULT_ENDPOINT_URL:
-        logger.info(f"AnnoFab WebAPIのエンドポイントURL: {endpoint_url}")
+        logger.info(f"Annofab WebAPIのエンドポイントURL: {endpoint_url}")
 
     try:
         return annofabapi.build_from_netrc(endpoint_url)
@@ -291,11 +324,11 @@ def build_annofabapi_resource(args: argparse.Namespace) -> annofabapi.Resource:
     # 標準入力から入力させる
     login_user_id = ""
     while login_user_id == "":
-        login_user_id = input("Enter AnnoFab User ID: ")
+        login_user_id = input("Enter Annofab User ID: ")
 
     login_password = ""
     while login_password == "":
-        login_password = getpass.getpass("Enter AnnoFab Password: ")
+        login_password = getpass.getpass("Enter Annofab Password: ")
 
     return annofabapi.build(login_user_id, login_password, endpoint_url=endpoint_url)
 
@@ -423,7 +456,8 @@ class ArgumentParser:
             help_message = (
                 "タスクを絞り込むためのクエリ条件をJSON形式で指定します。"
                 " ``file://`` を先頭に付けると、JSON形式のファイルを指定できます。"
-                "使用できるキーは、task_id, phase, phase_stage, status, user_id, account_id, no_user (bool値)  のみです。"
+                "使用できるキーは、``task_id`` , ``phase`` , ``phase_stage`` , ``status`` , ``user_id`` ,"
+                " ``account_id`` , ``no_user``  (bool値)  のみです。"
             )
         self.parser.add_argument("-tq", "--task_query", type=str, required=required, help=help_message)
 
@@ -488,7 +522,7 @@ class AbstractCommandLineWithoutWebapiInterface(abc.ABC):
             self.query = args.query
 
         if hasattr(args, "csv_format"):
-            self.csv_format = annofabcli.common.cli.get_csv_format_from_args(args.csv_format)
+            self.csv_format = get_csv_format_from_args(args.csv_format)
 
         if hasattr(args, "output"):
             self.output = args.output
@@ -496,8 +530,6 @@ class AbstractCommandLineWithoutWebapiInterface(abc.ABC):
         if hasattr(args, "format"):
             self.str_format = args.format
 
-        logger.info(f"args: {args}")
-
     def confirm_processing(self, confirm_message: str) -> bool:
         """
         `all_yes`属性を見て、処理するかどうかユーザに問い合わせる。
@@ -563,20 +595,40 @@ class AbstractCommandLineWithoutWebapiInterface(abc.ABC):
         return target
 
     def print_csv(self, df: pandas.DataFrame):
-        annofabcli.utils.print_csv(df, output=self.output, to_csv_kwargs=self.csv_format)
+        print_csv(df, output=self.output, to_csv_kwargs=self.csv_format)
 
     def print_according_to_format(self, target: Any):
         target = self.search_with_jmespath_expression(target)
 
-        annofabcli.utils.print_according_to_format(
+        print_according_to_format(
             target, arg_format=FormatArgument(self.str_format), output=self.output, csv_format=self.csv_format
         )
 
 
 class PrettyHelpFormatter(argparse.RawTextHelpFormatter, argparse.ArgumentDefaultsHelpFormatter):
     def _format_action(self, action: argparse.Action) -> str:
+        # ヘルプメッセージを見やすくするために、引数と引数の説明の間に空行を入れる
+        # https://qiita.com/yuji38kwmt/items/c7c4d487e3188afd781e 参照
         return super()._format_action(action) + "\n"
 
+    def _get_help_string(self, action):
+        # 必須な引数には、引数の説明の後ろに"(required)"を付ける
+        help = action.help  # pylint: disable=redefined-builtin
+        if action.required:
+            help += " (required)"
+
+        # 不要なデフォルト値（--debug や オプショナルな引数）を表示させないようにする
+        # super()._get_help_string の中身を、そのまま持ってきた。
+        # https://qiita.com/yuji38kwmt/items/c7c4d487e3188afd781e 参照
+        if "%(default)" not in action.help:
+            if action.default is not argparse.SUPPRESS:
+                defaulting_nargs = [argparse.OPTIONAL, argparse.ZERO_OR_MORE]
+                if action.option_strings or action.nargs in defaulting_nargs:
+                    # 以下の条件だけ、annofabcli独自の設定
+                    if action.default is not None and not action.const:
+                        help += " (default: %(default)s)"
+        return help
+
 
 class AbstractCommandLineInterface(AbstractCommandLineWithoutWebapiInterface):
     """
@@ -596,7 +648,7 @@ class AbstractCommandLineInterface(AbstractCommandLineWithoutWebapiInterface):
 
     def validate_project(
         self,
-        project_id,
+        project_id: str,
         project_member_roles: Optional[List[ProjectMemberRole]] = None,
         organization_member_roles: Optional[List[OrganizationMemberRole]] = None,
     ):
