@@ -73,17 +73,41 @@ class AbstractPhaseCumulativeProductivity(abc.ABC):
 
         return True
 
-    def _plot(self, line_graph_list: list[LineGraph], user_id_list: list[str], output_file: Path):
+    def _plot(
+        self,
+        line_graph_list: list[LineGraph],
+        columns_list: list[tuple[str, str]],
+        user_id_list: list[str],
+        output_file: Path,
+    ):
         """
         折れ線グラフを、HTMLファイルに出力します。
+
+        Args:
+            columns_list
         """
+
+        def get_required_columns() -> list[str]:
+            """
+            HTMLに出力するすべてのグラフから、必要な列名を取得します。
+
+            ColumnDataSourceを生成する際に、必要最小限のデータのみHTMLファイルに出力されるようにするためです。
+            そうしないと、不要な情報がHTMLファイルに出力されることにより、ファイルサイズが大きくなってしまいます。
+            たとえば、20000件をプロットする際、すべての列を出力すると、そうでないときに比べてファイルサイズが3倍以上になる
+            """
+            xy_columns = set(itertools.chain.from_iterable(columns for columns in columns_list))
+            tooltip_columns = set(
+                itertools.chain.from_iterable(
+                    line_graph.tooltip_columns
+                    for line_graph in line_graph_list
+                    if line_graph.tooltip_columns is not None
+                )
+            )
+            return list(xy_columns | tooltip_columns)
+
         df = self._df_cumulative
 
-        # HTMLに出力するすべてのグラフから、必要な列名を求める
-        # ColumnDataSourceを生成する際に、必要最小限のデータのみHTMLファイルに出力されるようにするため
-        # 不要な情報がHTMLファイルに出力されることにより、ファイルサイズが大きくなってしまう
-        # (例) 20000件をプロットする際、この対応がないと、ファイルサイズが3倍以上になる
-        required_columns = list(set(itertools.chain.from_iterable([e.required_columns for e in line_graph_list])))
+        required_columns = get_required_columns()
 
         line_count = 0
         for user_index, user_id in enumerate(user_id_list):
@@ -97,8 +121,8 @@ class AbstractPhaseCumulativeProductivity(abc.ABC):
             username = df_subset.iloc[0][f"first_{self.phase.value}_username"]
 
             line_count += 1
-            for line_graph in line_graph_list:
-                line_graph.add_line(source, legend_label=username, color=color)
+            for line_graph, (x_column, y_column) in zip(line_graph_list, columns_list):
+                line_graph.add_line(source, x_column=x_column, y_column=y_column, legend_label=username, color=color)
 
         if line_count == 0:
             logger.warning(f"プロットするデータがなかっため、'{output_file}'は出力しません。")
@@ -215,13 +239,11 @@ class AnnotatorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         user_id_list = get_plotted_user_id_list(user_id_list)
 
         x_axis_label = "アノテーション数"
-        x_column = "cumulative_annotation_count"
 
         line_graph_list = [
             LineGraph(
                 title="累積のアノテーション数と教師付作業時間",
                 y_axis_label="教師付作業時間[hour]",
-                y_column="cumulative_annotation_worktime_hour",
                 tooltip_columns=[
                     "task_id",
                     "first_annotation_user_id",
@@ -232,12 +254,10 @@ class AnnotatorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
             LineGraph(
                 title="累積のアノテーション数と検査コメント数",
                 y_axis_label="検査コメント数",
-                y_column="cumulative_inspection_comment_count",
                 tooltip_columns=[
                     "task_id",
                     "first_annotation_user_id",
@@ -247,11 +267,15 @@ class AnnotatorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
         ]
 
-        self._plot(line_graph_list, user_id_list, output_file)
+        x_column = "cumulative_annotation_count"
+        columns_list = [
+            (x_column, "cumulative_annotation_worktime_hour"),
+            (x_column, "cumulative_inspection_comment_count"),
+        ]
+        self._plot(line_graph_list, columns_list, user_id_list, output_file)
 
     def plot_input_data_metrics(
         self,
@@ -276,12 +300,10 @@ class AnnotatorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         user_id_list = get_plotted_user_id_list(user_id_list)
 
         x_axis_label = "入力データ数"
-        x_column = "cumulative_input_data_count"
 
         line_graph_list = [
             LineGraph(
                 title="累積の入力データ数と教師付作業時間",
-                y_column="cumulative_annotation_worktime_hour",
                 y_axis_label="教師付作業時間[hour]",
                 tooltip_columns=[
                     "task_id",
@@ -293,11 +315,9 @@ class AnnotatorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
             LineGraph(
                 title="累積の入力データ数と検査コメント数",
-                y_column="cumulative_inspection_comment_count",
                 y_axis_label="検査コメント数",
                 tooltip_columns=[
                     "task_id",
@@ -309,11 +329,16 @@ class AnnotatorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
         ]
 
-        self._plot(line_graph_list, user_id_list, output_file)
+        x_column = "cumulative_input_data_count"
+        columns_list = [
+            (x_column, "cumulative_annotation_worktime_hour"),
+            (x_column, "cumulative_inspection_comment_count"),
+        ]
+
+        self._plot(line_graph_list, columns_list, user_id_list, output_file)
 
     def plot_task_metrics(
         self,
@@ -338,7 +363,6 @@ class AnnotatorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         user_id_list = get_plotted_user_id_list(user_id_list)
 
         x_axis_label = "タスク数"
-        x_column = "cumulative_task_count"
         tooltip_columns = [
             "task_id",
             "first_annotation_user_id",
@@ -352,31 +376,32 @@ class AnnotatorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         line_graph_list = [
             LineGraph(
                 title="累積のタスク数と教師付作業時間",
-                y_column="cumulative_annotation_worktime_hour",
                 y_axis_label="教師付作業時間[hour]",
                 tooltip_columns=tooltip_columns,
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
             LineGraph(
                 title="累積のタスク数と差し戻し回数(検査フェーズ)",
-                y_column="cumulative_number_of_rejections_by_inspection",
                 y_axis_label="差し戻し回数(検査フェーズ)",
                 tooltip_columns=tooltip_columns,
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
             LineGraph(
                 title="累積のタスク数と差し戻し回数(受入フェーズ)",
-                y_column="cumulative_number_of_rejections_by_acceptance",
                 y_axis_label="差し戻し回数(受入フェーズ)",
                 tooltip_columns=tooltip_columns,
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
         ]
 
-        self._plot(line_graph_list, user_id_list, output_file)
+        x_column = "cumulative_task_count"
+        columns_list = [
+            (x_column, "cumulative_annotation_worktime_hour"),
+            (x_column, "cumulative_number_of_rejections_by_inspection"),
+            (x_column, "cumulative_number_of_rejections_by_acceptance"),
+        ]
+
+        self._plot(line_graph_list, columns_list, user_id_list, output_file)
 
 
 class InspectorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
@@ -452,12 +477,10 @@ class InspectorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         user_id_list = get_plotted_user_id_list(user_id_list)
 
         x_axis_label = "アノテーション数"
-        x_column = "cumulative_annotation_count"
 
         line_graph_list = [
             LineGraph(
                 title="累積のアノテーション数と検査作業時間",
-                y_column="cumulative_inspection_worktime_hour",
                 y_axis_label="検査作業時間[hour]",
                 tooltip_columns=[
                     "task_id",
@@ -469,11 +492,15 @@ class InspectorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
         ]
 
-        self._plot(line_graph_list, user_id_list, output_file)
+        x_column = "cumulative_annotation_count"
+        columns_list = [
+            (x_column, "cumulative_inspection_worktime_hour"),
+        ]
+
+        self._plot(line_graph_list, columns_list, user_id_list, output_file)
 
     def plot_input_data_metrics(
         self,
@@ -498,12 +525,10 @@ class InspectorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         user_id_list = get_plotted_user_id_list(user_id_list)
 
         x_axis_label = "入力データ数"
-        x_column = "cumulative_input_data_count"
 
         line_graph_list = [
             LineGraph(
                 title="累積の入力データ数と検査作業時間",
-                y_column="cumulative_inspection_worktime_hour",
                 y_axis_label="検査作業時間[hour]",
                 tooltip_columns=[
                     "task_id",
@@ -515,11 +540,15 @@ class InspectorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
         ]
 
-        self._plot(line_graph_list, user_id_list, output_file)
+        x_column = "cumulative_input_data_count"
+        columns_list = [
+            (x_column, "cumulative_inspection_worktime_hour"),
+        ]
+
+        self._plot(line_graph_list, columns_list, user_id_list, output_file)
 
     def plot_task_metrics(
         self,
@@ -544,12 +573,10 @@ class InspectorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         user_id_list = get_plotted_user_id_list(user_id_list)
 
         x_axis_label = "タスク数"
-        x_column = "cumulative_task_count"
 
         line_graph_list = [
             LineGraph(
                 title="累積のタスク数と検査作業時間",
-                y_column="cumulative_inspection_worktime_hour",
                 y_axis_label="検査作業時間[hour]",
                 tooltip_columns=[
                     "task_id",
@@ -560,11 +587,15 @@ class InspectorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
         ]
 
-        self._plot(line_graph_list, user_id_list, output_file)
+        x_column = "cumulative_task_count"
+        columns_list = [
+            (x_column, "cumulative_inspection_worktime_hour"),
+        ]
+
+        self._plot(line_graph_list, columns_list, user_id_list, output_file)
 
 
 class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
@@ -635,12 +666,10 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         user_id_list = get_plotted_user_id_list(user_id_list)
 
         x_axis_label = "アノテーション数"
-        x_column = "cumulative_annotation_count"
 
         line_graph_list = [
             LineGraph(
                 title="累積のアノテーション数と受入作業時間",
-                y_column="cumulative_acceptance_worktime_hour",
                 y_axis_label="受入作業時間[hour]",
                 tooltip_columns=[
                     "task_id",
@@ -652,10 +681,15 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
         ]
-        self._plot(line_graph_list, user_id_list, output_file)
+
+        x_column = "cumulative_annotation_count"
+        columns_list = [
+            (x_column, "cumulative_acceptance_worktime_hour"),
+        ]
+
+        self._plot(line_graph_list, columns_list, user_id_list, output_file)
 
     def plot_input_data_metrics(
         self,
@@ -680,12 +714,10 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         user_id_list = get_plotted_user_id_list(user_id_list)
 
         x_axis_label = "入力データ数"
-        x_column = "cumulative_input_data_count"
 
         line_graph_list = [
             LineGraph(
                 title="累積の入力データ数と受入作業時間",
-                y_column="cumulative_acceptance_worktime_hour",
                 y_axis_label="受入作業時間[hour]",
                 tooltip_columns=[
                     "task_id",
@@ -697,11 +729,15 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
         ]
 
-        self._plot(line_graph_list, user_id_list, output_file)
+        x_column = "cumulative_input_data_count"
+        columns_list = [
+            (x_column, "cumulative_acceptance_worktime_hour"),
+        ]
+
+        self._plot(line_graph_list, columns_list, user_id_list, output_file)
 
     def plot_task_metrics(
         self,
@@ -724,12 +760,10 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
         user_id_list = get_plotted_user_id_list(user_id_list)
 
         x_axis_label = "タスク数"
-        x_column = "cumulative_task_count"
 
         line_graph_list = [
             LineGraph(
                 title="累積のタスク数と受入作業時間",
-                y_column="cumulative_acceptance_worktime_hour",
                 y_axis_label="受入作業時間[hour]",
                 tooltip_columns=[
                     "task_id",
@@ -740,8 +774,12 @@ class AcceptorCumulativeProductivity(AbstractPhaseCumulativeProductivity):
                     "inspection_comment_count",
                 ],
                 x_axis_label=x_axis_label,
-                x_column=x_column,
             ),
         ]
 
-        self._plot(line_graph_list, user_id_list, output_file)
+        x_column = "cumulative_task_count"
+        columns_list = [
+            (x_column, "cumulative_acceptance_worktime_hour"),
+        ]
+
+        self._plot(line_graph_list, columns_list, user_id_list, output_file)
