@@ -8,10 +8,10 @@ import annofabapi
 from annofabapi.models import TaskHistory
 
 import annofabcli
-from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import AbstractCommandLineInterface, ArgumentParser, build_annofabapi_resource_and_login
 from annofabcli.common.download import DownloadingFile
 from annofabcli.common.enums import FormatArgument
+from annofabcli.common.facade import AnnofabApiFacade
 from annofabcli.common.visualize import AddProps
 
 logger = logging.getLogger(__name__)
@@ -47,7 +47,7 @@ class ListTaskHistoryWithJsonMain:
         """出力対象のタスク履歴情報を取得する"""
         if task_history_json is None:
             downloading_obj = DownloadingFile(self.service)
-            cache_dir = annofabcli.utils.get_cache_dir()
+            cache_dir = annofabcli.common.utils.get_cache_dir()
             json_path = cache_dir / f"{project_id}-task_history.json"
 
             downloading_obj.download_task_history_json(project_id, str(json_path))
